# SVM XSS DETECT Package

This is a simple example package for detecting XSS payload using SVM. You can use
[Github-flavored Markdown](https://github.ccs.neu.edu/Capstone-Team/svm)
to write your content.
